@@ -13,8 +13,9 @@ void ppspolya(double *y, double *size, double *w, int *nin, int *Nin)
 
 	for (i=n; i<N; i++) {
 		a = w[i-1] * unif_rand();
-		j = 0;
-		while(a > w[j]){j++;}
+                for (j=0; j<N; j++){
+                  if(a <= w[j]) break;
+                }
 		y[i] = y[j];
 		size[i] = size[j];
 	}
